@@ -1,7 +1,7 @@
 #pragma once
 #include <QLatin1String>
 
-#define KWIN_PLUGIN_VERSION_STRING "6.5.4"
+#define KWIN_PLUGIN_VERSION_STRING "6.5.5"
 
 #define KWIN_BUILD_DECORATIONS 1
 #define KWIN_BUILD_KCMS 1
@@ -13,7 +13,7 @@
 constexpr QLatin1String KWIN_DATADIR("kwin-x11");
 constexpr QLatin1String KWIN_PLUGINDIR("kwin-x11");
 constexpr QLatin1String KWIN_CONFIG("kwinrc");
-constexpr QLatin1String KWIN_VERSION_STRING("6.5.4");
+constexpr QLatin1String KWIN_VERSION_STRING("6.5.5");
 constexpr QLatin1String XCB_VERSION_STRING("1.17.0");
 constexpr QLatin1String KWIN_KILLER_BIN("/usr/lib/kwin_killer_helper_x11");
 #define HAVE_X11_XCB 1
@@ -34,4 +34,4 @@ constexpr QLatin1String BREEZE_KDECORATION_PLUGIN_ID("org.kde.breeze");
 #define HAVE_WL_DISPLAY_SET_DEFAULT_MAX_BUFFER_SIZE 1
 #define HAVE_WL_FIXES 1
 
-constexpr QLatin1String XWAYLAND_SESSION_SCRIPTS("/etc/xdg/Xwayland-session.d");
+constexpr QLatin1String XWAYLAND_SESSION_SCRIPTS("");
